@@ -344,25 +344,31 @@ class SFREAD:
         if data.obj_type not in (6, 7):
             logging.error('Calibration failed for %s: no Sig, no SGR', obj)
             return data
+
         pscal = self.lincalib(obj)
-        if pscal is not None:
-            for j in range(10):
-                mult = 'MULTIA0%d' %j
-                shif = 'SHIFTB0%d' %j
-                if mult in pscal.keys():
+        if pscal is None:
+            return data
+
+        for j in range(10):
+            mult = 'MULTIA0%d' %j
+            shif = 'SHIFTB0%d' %j
+            if mult in pscal.keys():
 # we need to fix the content of pscal for signagroups
 # assuming first entry wins
-                    if j == 0:
-                        dout = data*1. # Creates a copy of a read-only array, only once
-                        dout.calib = True
-                    if (pscal[mult].size > 1):
-                        pscal[mult] = pscal[mult][0]
-                        pscal[shif] = pscal[shif][0]
-                    dout *= pscal[mult]
-                    dout += pscal[shif]
-                else:
-                    break
-        return dout
+                if j == 0:
+                    dout = data*1. # Creates a copy of a read-only array, only once
+                    dout.calib = True
+                if (pscal[mult].size > 1):
+                    pscal[mult] = pscal[mult][0]
+                    pscal[shif] = pscal[shif][0]
+                dout *= pscal[mult]
+                dout += pscal[shif]
+            else:
+                break
+        if 'dout' in locals():
+            return dout
+        else:
+            return data
 
 
     def lincalib(self, obj):
